@@ -4,47 +4,87 @@
 #use Test;
 
 use strict;
+use Test::More;
 
 use constant USERID	=> "GnuPG Test";
 use constant PASSWD	=> "test";
 use constant UNTRUSTED	=> "Francis";
 
 use Symbol;
+use GnuPG;
+use GnuPG::Tie::Encrypt;
+use GnuPG::Tie::Decrypt;
 
 BEGIN {
     $| = 1;
 }
 
-use GnuPG;
-use GnuPG::Tie::Encrypt;
-use GnuPG::Tie::Decrypt;
+my @tests = qw(
+                gen_key_test
+                import_test
+                import2_test
+                import3_test
+                export_test
+                export2_test
+                export_secret_test
+                encrypt_test
+                pipe_encrypt_test
+                pipe_decrypt_test
+                encrypt_sign_test
+                encrypt_sym_test
+                encrypt_notrust_test
+                decrypt_test
+                decrypt_sign_test
+                decrypt_sym_test
+                sign_test
+                detachsign_test
+                clearsign_test
+                verify_sign_test
+                verify_detachsign_test
+                verify_clearsign_test
+                tie_encrypt_test
+                tie_decrypt_test
+                tie_decrypt_para_mode_test
+    	        );
+
+if ( defined $ENV{TESTS} ) {
+    @tests = split /\s+/, $ENV{TESTS};
+}
+
+plan tests => scalar @tests;
 
 my $gpg = new GnuPG( homedir => "test", trace => $ENV{TRACING} );
 
+for ( @tests ) {
+    eval {
+	    no strict 'refs';   # We are using symbolic references
+	    &$_();
+    };
+
+    (ok !$@, $_) || diag $@;
+}
+
+
 sub gen_key_test {
-    printf "%-40s", "Key generation";
+    diag "Generating a key - can take some time";
     $gpg->gen_key(
 		  passphrase => PASSWD,
 		  name	     => USERID,
-		 );
+    );
 }
 
 sub import_test {
-    printf "%-40s", "Import new public key";
     $gpg->import_keys( keys => "test/key1.pub" );
 }
 
 sub import2_test {
-    printf "%-40s", "Import existing public key";
     $gpg->import_keys( keys => "test/key1.pub" );
 }
 
 sub import3_test {
-    printf "%-40s", "Import many public keys";
     $gpg->import_keys( keys => [ qw( test/key1.pub test/key2.pub ) ] );
 }
 sub export_test {
-    printf "%-40s", "Public key export";
     $gpg->export_keys( keys	=> USERID,
 		       armor	=> 1,
 		       output	=> "test/key.pub",
@@ -52,14 +92,12 @@ sub export_test {
 }
 
 sub export2_test {
-    printf "%-40s", "Exporting public key ring";
     $gpg->export_keys( armor	=> 1,
 		       output	=> "test/keyring.pub",
 		     );
 }
 
 sub export_secret_test {
-    printf "%-40s", "Exporting secret key";
     $gpg->export_keys( secret	=> 1,
 		       armor	=> 1,
 		       output	=> "test/key.sec",
@@ -67,7 +105,6 @@ sub export_secret_test {
 }
 
 sub encrypt_test {
-    printf "%-40s", "Encrypt";
     $gpg->encrypt(
 		  recipient => USERID,
 		  output    => "test/file.txt.gpg",
@@ -77,7 +114,6 @@ sub encrypt_test {
 }
 
 sub pipe_encrypt_test {
-    printf "%-40s", "Pipe Encrypt";
     open CAT, "| cat > test/pipe-file.txt.gpg"
       or die "can't fork: $!\n";
     $gpg->encrypt(
@@ -90,7 +126,6 @@ sub pipe_encrypt_test {
 }
 
 sub encrypt_sign_test {
-    printf "%-40s", "Encrypt and Sign";
     $gpg->encrypt(
 		  recipient	=> USERID,
 		  output	=> "test/file.txt.sgpg",
@@ -102,7 +137,6 @@ sub encrypt_sign_test {
 }
 
 sub encrypt_sym_test {
-    printf "%-40s", "Symmetric encryption";
     $gpg->encrypt(
 		  output	=> "test/file.txt.cipher",
 		  armor		=> 1,
@@ -113,7 +147,6 @@ sub encrypt_sym_test {
 }
 
 sub encrypt_notrust_test {
-    printf "%-40s", "Encrypt to undefined trust";
     $gpg->encrypt(
 		  recipient	=> UNTRUSTED,
 		  output	=> "test/file.txt.dist.gpg",
@@ -125,7 +158,6 @@ sub encrypt_notrust_test {
 }
 
 sub sign_test {
-    printf "%-40s", "Sign a file";
     $gpg->sign(
 		  recipient	=> USERID,
 		  output	=> "test/file.txt.sig",
@@ -136,7 +168,6 @@ sub sign_test {
 }
 
 sub detachsign_test {
-    printf "%-40s", "Detach signature of a file";
     $gpg->sign(
 		  recipient	=> USERID,
 		  output	=> "test/file.txt.asc",
@@ -148,7 +179,6 @@ sub detachsign_test {
 }
 
 sub clearsign_test {
-    printf "%-40s", "Clear Sign a File";
     $gpg->clearsign(
 		    output	=> "test/file.txt.clear",
 		    armor	=> 1,
@@ -158,7 +188,6 @@ sub clearsign_test {
 }
 
 sub decrypt_test {
-    printf "%-40s", "Decrypt a file";
     $gpg->decrypt(
 		    output	=> "test/file.txt.plain",
 		    ciphertext	=> "test/file.txt.gpg",
@@ -166,7 +195,6 @@ sub decrypt_test {
 		 );
 }
 sub pipe_decrypt_test {
-    printf "%-40s", "Pipe Decrypt";
     open CAT, "cat test/file.txt.gpg|"
       or die "can't fork: $!\n";
     $gpg->decrypt(
@@ -178,7 +206,6 @@ sub pipe_decrypt_test {
 }
 
 sub decrypt_sign_test {
-    printf "%-40s", "Decrypt a Signed File";
     $gpg->decrypt(
 		    output	=> "test/file.txt.plain2",
 		    ciphertext	=> "test/file.txt.sgpg",
@@ -187,7 +214,6 @@ sub decrypt_sign_test {
 }
 
 sub decrypt_sym_test {
-    printf "%-40s", "Symmetric decryption";
     $gpg->decrypt(
 		    output	=> "test/file.txt.plain3",
 		    ciphertext	=> "test/file.txt.cipher",
@@ -197,24 +223,20 @@ sub decrypt_sym_test {
 }
 
 sub verify_sign_test {
-    printf "%-40s", "Verify a signed file";
     $gpg->verify( signature	=> "test/file.txt.sig" );
 }
 
 sub verify_detachsign_test {
-    printf "%-40s", "Verify a detach signature";
     $gpg->verify( signature	=> "test/file.txt.asc",
 		  file		=> "test/file.txt",
 		);
 }
 
 sub verify_clearsign_test {
-    printf "%-40s", "Verify a clearsigned file";
     $gpg->verify( signature => "test/file.txt.clear" );
 }
 
 sub encrypt_from_fh_test {
-    printf "%-40s", "Encrypt from file handle";
     open ( FH, "test/file.txt" )
       or die "error opening file: $!\n";
     $gpg->encrypt(
@@ -228,7 +250,6 @@ sub encrypt_from_fh_test {
 }
 
 sub encrypt_to_fh_test {
-    printf "%-40s", "Encrypt to file handle";
     open ( FH, ">test/file-fho.txt.gpg" )
       or die "error opening file: $!\n";
     $gpg->encrypt(
@@ -242,7 +263,6 @@ sub encrypt_to_fh_test {
 }
 
 sub tie_encrypt_test {
-    printf "%-40s", "Tied encrypt interface";
     open( PLAINTEXT, "test/file.txt" )
       or die "error opening file: $!\n";
     open( CIPHER_OUT, ">test/file-tie.txt.asc" )
@@ -263,7 +283,6 @@ sub tie_encrypt_test {
 }
 
 sub tie_decrypt_test {
-    printf "%-40s", "Tied decrypt interface";
     open( PLAINTEXT, "test/file.txt" )
       or die "error opening plaintext file: $!\n";
     my $plaintext_orig = "";
@@ -290,7 +309,6 @@ sub tie_decrypt_test {
 }
 
 sub tie_decrypt_para_mode_test {
-    printf "%-40s", "Tied decrypt in paragraph mode";
     my $plaintext = <<EOF;
 This is a paragraph.
 
@@ -322,38 +340,3 @@ EOF
     die "paragraph count should be 3: $count\n" unless $count == 3;
     die "plaintext doesn't match input\n" unless join( "", @para) eq $plaintext;
 }
-
-my @tests = qw(
-                gen_key_test
-    		import_test	 import2_test		import3_test
-    		export_test	 export2_test		export_secret_test
-    		encrypt_test	 pipe_encrypt_test	pipe_decrypt_test
-		encrypt_sign_test encrypt_sym_test
-    		encrypt_notrust_test
-    		decrypt_test	 decrypt_sign_test	decrypt_sym_test
-    		sign_test	 detachsign_test	clearsign_test
-    		verify_sign_test verify_detachsign_test verify_clearsign_test
-		tie_encrypt_test tie_decrypt_test tie_decrypt_para_mode_test
-    	        );
-
-if ( defined $ENV{TESTS} ) {
-    @tests = split /\s+/, $ENV{TESTS};
-}
-
-print "1..", scalar @tests, "\n";
-my $i = 1;
-for ( @tests ) {
-    eval { 
-	no strict 'refs';   # We are using symbolic references
-	&$_();
-    };
-    if ( $@ ) {
-	print "not ok $i: $@";
-    } else {
-	print "ok $i\n";
-    }
-    $i++;
-}
-
-
-
